@@ -10,9 +10,10 @@ import (
 
 func privateCommand() *cobra.Command {
 	cmd := &cobra.Command{
-		Use:   "private REPOSITORY [true|false]",
-		Short: "Set or get a repository private property",
-		Args:  cobra.RangeArgs(1, 2),
+		Use:               "private REPOSITORY [true|false]",
+		Short:             "Set or get a repository private property",
+		Args:              cobra.RangeArgs(1, 2),
+		PersistentPreRunE: checkIfReadable,
 		RunE: func(cmd *cobra.Command, args []string) error {
 			ctx := cmd.Context()
 			be := backend.FromContext(ctx)
@@ -20,10 +21,6 @@ func privateCommand() *cobra.Command {
 
 			switch len(args) {
 			case 1:
-				if err := checkIfReadable(cmd, args); err != nil {
-					return err
-				}
-
 				isPrivate, err := be.IsPrivate(ctx, rn)
 				if err != nil {
 					return err
