@@ -10,10 +10,11 @@ import (
 	"net/http"
 	"os"
 	"path/filepath"
+	"strconv"
 	"strings"
 	"time"
 
-	"github.com/charmbracelet/log"
+	"github.com/charmbracelet/log/v2"
 	gitb "github.com/charmbracelet/soft-serve/git"
 	"github.com/charmbracelet/soft-serve/pkg/access"
 	"github.com/charmbracelet/soft-serve/pkg/backend"
@@ -123,7 +124,7 @@ var gitRoutes = []GitRoute{
 	{
 		method:  []string{http.MethodPost},
 		handler: serviceRpc,
-		path:    "/{service:(?:git-upload-pack|git-receive-pack)$}",
+		path:    "/{service:(?:git-upload-archive|git-upload-pack|git-receive-pack)$}",
 	},
 	{
 		method:  []string{http.MethodGet},
@@ -273,7 +274,7 @@ func withAccess(next http.Handler) http.HandlerFunc {
 			}
 
 			fallthrough
-		case service == git.UploadPackService:
+		case service == git.UploadPackService || service == git.UploadArchiveService:
 			if repo == nil {
 				// If the repo doesn't exist, return 404
 				renderNotFound(w, r)
@@ -393,7 +394,11 @@ func serviceRpc(w http.ResponseWriter, r *http.Request) {
 	cmd := git.ServiceCommand{
 		Stdout: &stdout,
 		Dir:    dir,
-		Args:   []string{"--stateless-rpc"},
+	}
+
+	switch service {
+	case git.UploadPackService, git.ReceivePackService:
+		cmd.Args = append(cmd.Args, "--stateless-rpc")
 	}
 
 	user := proto.UserFromContext(ctx)
@@ -441,7 +446,7 @@ func serviceRpc(w http.ResponseWriter, r *http.Request) {
 	}
 
 	if service == git.ReceivePackService {
-		if err := git.EnsureDefaultBranch(ctx, cmd); err != nil {
+		if err := git.EnsureDefaultBranch(ctx, cmd.Dir); err != nil {
 			logger.Errorf("failed to ensure default branch: %s", err)
 		}
 	}
@@ -485,7 +490,7 @@ func getInfoRefs(w http.ResponseWriter, r *http.Request) {
 	cfg := config.FromContext(ctx)
 	dir, repoName, file := mux.Vars(r)["dir"], mux.Vars(r)["repo"], mux.Vars(r)["file"]
 	service := getServiceType(r)
-	version := r.Header.Get("Git-Protocol")
+	protocol := r.Header.Get("Git-Protocol")
 
 	gitHttpUploadCounter.WithLabelValues(repoName, file).Inc()
 
@@ -510,8 +515,17 @@ func getInfoRefs(w http.ResponseWriter, r *http.Request) {
 				"SOFT_SERVE_USERNAME=" + user.Username(),
 			}...)
 		}
-		if len(version) != 0 {
-			cmd.Env = append(cmd.Env, fmt.Sprintf("GIT_PROTOCOL=%s", version))
+		if len(protocol) != 0 {
+			cmd.Env = append(cmd.Env, fmt.Sprintf("GIT_PROTOCOL=%s", protocol))
+		}
+
+		var version int
+		for _, p := range strings.Split(protocol, ":") {
+			if strings.HasPrefix(p, "version=") {
+				if v, _ := strconv.Atoi(p[8:]); v > version {
+					version = v
+				}
+			}
 		}
 
 		if err := service.Handler(ctx, cmd); err != nil {
@@ -522,10 +536,9 @@ func getInfoRefs(w http.ResponseWriter, r *http.Request) {
 		hdrNocache(w)
 		w.Header().Set("Content-Type", fmt.Sprintf("application/x-%s-advertisement", service))
 		w.WriteHeader(http.StatusOK)
-		if len(version) == 0 {
+		if version < 2 {
 			git.WritePktline(w, "# service="+service.String()) // nolint: errcheck
 		}
-
 		w.Write(refs.Bytes()) // nolint: errcheck
 	} else {
 		// Dumb HTTP
