@@ -5,15 +5,16 @@ import (
 	"net/http"
 	"time"
 
-	"github.com/charmbracelet/log"
+	"github.com/charmbracelet/log/v2"
 	"github.com/charmbracelet/soft-serve/pkg/config"
 )
 
 // HTTPServer is an http server.
 type HTTPServer struct {
-	ctx    context.Context
-	cfg    *config.Config
-	server *http.Server
+	ctx context.Context
+	cfg *config.Config
+
+	Server *http.Server
 }
 
 // NewHTTPServer creates a new HTTP server.
@@ -23,7 +24,7 @@ func NewHTTPServer(ctx context.Context) (*HTTPServer, error) {
 	s := &HTTPServer{
 		ctx: ctx,
 		cfg: cfg,
-		server: &http.Server{
+		Server: &http.Server{
 			Addr:              cfg.HTTP.ListenAddr,
 			Handler:           NewRouter(ctx),
 			ReadHeaderTimeout: time.Second * 10,
@@ -38,18 +39,18 @@ func NewHTTPServer(ctx context.Context) (*HTTPServer, error) {
 
 // Close closes the HTTP server.
 func (s *HTTPServer) Close() error {
-	return s.server.Close()
+	return s.Server.Close()
 }
 
 // ListenAndServe starts the HTTP server.
 func (s *HTTPServer) ListenAndServe() error {
 	if s.cfg.HTTP.TLSKeyPath != "" && s.cfg.HTTP.TLSCertPath != "" {
-		return s.server.ListenAndServeTLS(s.cfg.HTTP.TLSCertPath, s.cfg.HTTP.TLSKeyPath)
+		return s.Server.ListenAndServeTLS(s.cfg.HTTP.TLSCertPath, s.cfg.HTTP.TLSKeyPath)
 	}
-	return s.server.ListenAndServe()
+	return s.Server.ListenAndServe()
 }
 
 // Shutdown gracefully shuts down the HTTP server.
 func (s *HTTPServer) Shutdown(ctx context.Context) error {
-	return s.server.Shutdown(ctx)
+	return s.Server.Shutdown(ctx)
 }
