@@ -10,7 +10,9 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"net"
 	"net/http"
+	"time"
 
 	"github.com/charmbracelet/soft-serve/git"
 	"github.com/charmbracelet/soft-serve/pkg/db"
@@ -36,6 +38,43 @@ type Delivery struct {
 	Event Event
 }
 
+// secureHTTPClient creates an HTTP client with SSRF protection.
+var secureHTTPClient = &http.Client{
+	Timeout: 30 * time.Second,
+	Transport: &http.Transport{
+		DialContext: func(ctx context.Context, network, addr string) (net.Conn, error) {
+			// Parse the address to get the IP
+			host, _, err := net.SplitHostPort(addr)
+			if err != nil {
+				return nil, err //nolint:wrapcheck
+			}
+
+			// Validate the resolved IP before connecting
+			ip := net.ParseIP(host)
+			if ip != nil {
+				if err := ValidateIPBeforeDial(ip); err != nil {
+					return nil, fmt.Errorf("blocked connection to private IP: %w", err)
+				}
+			}
+
+			// Use standard dialer with timeout
+			dialer := &net.Dialer{
+				Timeout:   10 * time.Second,
+				KeepAlive: 30 * time.Second,
+			}
+			return dialer.DialContext(ctx, network, addr)
+		},
+		MaxIdleConns:          100,
+		IdleConnTimeout:       90 * time.Second,
+		TLSHandshakeTimeout:   10 * time.Second,
+		ExpectContinueTimeout: 1 * time.Second,
+	},
+	// Don't follow redirects to prevent bypassing IP validation
+	CheckRedirect: func(*http.Request, []*http.Request) error {
+		return http.ErrUseLastResponse
+	},
+}
+
 // do sends a webhook.
 // Caller must close the returned body.
 func do(ctx context.Context, url string, method string, headers http.Header, body io.Reader) (*http.Response, error) {
@@ -45,7 +84,7 @@ func do(ctx context.Context, url string, method string, headers http.Header, bod
 	}
 
 	req.Header = headers
-	res, err := http.DefaultClient.Do(req)
+	res, err := secureHTTPClient.Do(req)
 	if err != nil {
 		return nil, err
 	}
